==> dab-1.0.5.tar.gz: dab/src/Controller/DabComponentListController.php <==
<?php

namespace Drupal\dab\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Theme\ComponentPluginManager;
use Drupal\Core\Url;
use Drupal\dab\Form\ComponentFilterForm;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Defines DabComponentListController class.
 */
final class DabComponentListController extends ControllerBase {

  /**
   * The component plugin manager.
   *
   * @var \Drupal\sdc\ComponentPluginManager
   */
  protected $componentPluginManager;

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * The current stack.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $currentRequest;

  /**
   * DabComponentListController constructor.
   *
   * @param \Drupal\sdc\ComponentPluginManager $componentPluginManager
   *   The component plugin manager.
   * @param \Drupal\Core\Form\FormBuilderInterface $formBuilder
   *   The form builder.
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   *   The request stack.
   */
  public function __construct(
    ComponentPluginManager $componentPluginManager,
    FormBuilderInterface $formBuilder,
    RequestStack $requestStack,
  ) {
    $this->componentPluginManager = $componentPluginManager;
    $this->formBuilder = $formBuilder;
    $this->currentRequest = $requestStack->getCurrentRequest();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.sdc'),
      $container->get('form_builder'),
      $container->get('request_stack')
    );
  }

  /**
   * Returns the title for the component list.
   *
   * @param string|null $component_type
   *   The component type.
   *
   * @return string
   *   TThe title.
   */
  public function getTitle($component_type = NULL) {
    return is_null($component_type)
      ? 'Drupal Atomic Builder'
      : $this->t(
        '@component_type',
        ['@component_type' => ucfirst($component_type)]
      );
  }

  /**
   * Build the page data.
   *
   * @return array
   *   Return template and data.
   */
  public function build($component_type = NULL) {
    $componentList = [];
    $allComponents = [];

    $filter = $this->currentRequest->query->get('filter') ?: '';

    try {
      $components = $this->componentPluginManager->getAllComponents();
    }
    catch (\Exception $e) {
      $this->messenger()->addError($e->getMessage());
      return [];
    }

    /** @var \Drupal\sdc\Plugin\Component $component */
    foreach ($components as $component) {
      $pluginDefinition = $component->getPluginDefinition();
      $componentName = $pluginDefinition['machineName'];
      $pluginId = $component->getPluginId();
      $group = $pluginDefinition['group'] ?? 'other';

      if (!isset($componentList[$group])) {
        $componentList[$group] = [
          'title' => ucfirst($group),
          'url' => Url::fromRoute('dab.component_type_list', ['component_type' => $group]),
          'class' => [
            ...($component_type === $group ? ['active'] : []),
          ],
        ];
      }

      if (!empty($filter) && strpos($componentName, $filter) === FALSE) {
        continue;
      }

      $componentList[$group]['components'][$pluginId] = [
        'title' => ($pluginDefinition['name'] ?? ucfirst($componentName)),
        'machine_name' => $pluginId,
        'description' => $pluginDefinition['description'] ?? '',
        'url' => Url::fromRoute('dab.component', [
          'component_type' => $group,
          'machine_name' => $componentName,
          'provider' => $pluginDefinition['provider'],
        ]),
      ];

      $allComponents[$pluginId] = $componentList[$group]['components'][$pluginId];
    }

    ksort($componentList);

    return [
      '#theme' => 'dab_component_list',
      '#components_types' => $componentList,
      '#components' => empty($component_type) ? $allComponents : $componentList[$component_type]['components'],
      '#form' => $this->formBuilder->getForm(ComponentFilterForm::class),
      '#attached' => [
        'library' => [
          'dab/global',
        ],
      ],
    ];
  }

}

==> dab-1.0.7.tar.gz: dab/src/Controller/DabComponentListController.php <==
<?php

namespace Drupal\dab\Controller;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Theme\ComponentPluginManager;
use Drupal\Core\Url;
use Drupal\dab\Form\ComponentFilterForm;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Defines DabComponentListController class.
 */
final class DabComponentListController implements ContainerInjectionInterface {

  use MessengerTrait;
  use StringTranslationTrait;

  /**
   * The component plugin manager.
   *
   * @var \Drupal\Core\Theme\ComponentPluginManager
   */
  protected ComponentPluginManager $componentPluginManager;

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected FormBuilderInterface $formBuilder;

  /**
   * The current stack.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected Request $currentRequest;

  /**
   * Constructs a new Drupal\dab\Controller\DabComponentListController object.
   */
  public function __construct(
    ComponentPluginManager $componentPluginManager,
    FormBuilderInterface $formBuilder,
    RequestStack $requestStack,
  ) {
    $this->componentPluginManager = $componentPluginManager;
    $this->formBuilder = $formBuilder;
    $this->currentRequest = $requestStack->getCurrentRequest();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.sdc'),
      $container->get('form_builder'),
      $container->get('request_stack'),
    );
  }

  /**
   * Returns the title for the component list.
   *
   * @param string|null $component_type
   *   The component type.
   *
   * @return string
   *   The title.
   */
  public function getTitle($component_type = NULL) {
    return is_null($component_type)
      ? 'Drupal Atomic Builder'
      : $this->t(
        '@component_type',
        ['@component_type' => ucfirst($component_type)]
      );
  }

  /**
   * Check if the component is excluded from the list.
   *
   * @param string $componentName
   *   The component name.
   * @param string $extensionValue
   *   The extension value.
   *
   * @return bool
   *   Return true if the component is excluded.
   */
  private function isComponentExcluded(string $componentName, string $extensionValue): bool {
    $filter = $this->currentRequest->query->get('filter') ?? '';
    $extensionFilter = $this->currentRequest->query->get('extension_type') ?? '';

    $isFiltered = !empty($filter) && strpos($componentName, $filter) === FALSE;
    $isExtensionFiltered = !empty($extensionFilter) && $extensionValue !== $extensionFilter;

    return $isFiltered || $isExtensionFiltered;
  }

  /**
   * Build the page data.
   *
   * @return array
   *   Return template and data.
   */
  public function build($component_type = NULL) {
    $componentList = [];
    $allComponents = [];

    try {
      $components = $this->componentPluginManager->getAllComponents();
    }
    catch (\Exception $e) {
      $this->messenger()->addError($e->getMessage());
      return [];
    }

    /** @var \Drupal\Core\Plugin\Component $component */
    foreach ($components as $component) {
      $pluginDefinition = $component->getPluginDefinition();
      $componentName = $pluginDefinition['machineName'];
      $pluginId = $component->getPluginId();
      $group = $pluginDefinition['group'] ?? 'other';
      $extension = $pluginDefinition['extension_type'] ?? '';

      if (!isset($componentList[$group])) {
        $componentList[$group] = [
          'title' => ucfirst($group),
          'url' => Url::fromRoute('dab.component_type_list', ['component_type' => $group]),
          'class' => [
            ...($component_type === $group ? ['active'] : []),
          ],
        ];
      }

      if ($this->isComponentExcluded($componentName, $extension->value)) {
        continue;
      }

      $componentList[$group]['components'][$pluginId] = [
        'title' => ($pluginDefinition['name'] ?? ucfirst($componentName)),
        'machine_name' => $pluginId,
        'description' => $pluginDefinition['description'] ?? '',
        'extension' => $pluginDefinition['extension_type'] ?? '',
        'url' => Url::fromRoute('dab.component', [
          'component_type' => $group,
          'machine_name' => $componentName,
          'provider' => $pluginDefinition['provider'],
        ]),
      ];

      $allComponents[$pluginId] = $componentList[$group]['components'][$pluginId];
    }

    ksort($componentList);

    return [
      '#theme' => 'dab_component_list',
      '#components_types' => $componentList,
      '#components' => empty($component_type) || empty($componentList[$component_type]['components']) ? $allComponents : $componentList[$component_type]['components'],
      '#form' => $this->formBuilder->getForm(ComponentFilterForm::class),
      '#attached' => [
        'library' => [
          'dab/global',
        ],
      ],
    ];
  }

}
